@@ -24,6 +24,7 @@
 
 #include "sourcesmodel.h"
 #include "preview.h"
+#include "draghelper.h"
 
 #include <QtQml/qqml.h>
 
@@ -35,5 +36,6 @@ void QmlPlugins::registerTypes(const char *uri)
 {
     qmlRegisterType<Milou::SourcesModel> (uri, 0, 1, "SourcesModel");
     qmlRegisterType<Milou::Preview> (uri, 0, 1, "Preview");
+    qmlRegisterType<Milou::DragHelper> (uri, 0, 2, "DragHelper");
 }
 
